		------------------------------------
		-- Paragon Reputation 1.03 by Sev --
		------------------------------------

local faction = CreateFrame("frame") -- FactionsNames
local id = {} -- FactionsID
local rep = {} -- FactionsRep
local gained = {} -- RepGained
local check = false -- DuplicateErrorFix

faction:RegisterEvent("PLAYER_LOGIN"); -- RegisterLogin/Reload

		--------------------------------
		-- Localization for "Paragon" --
		--------------------------------

--[[I used Wowhead to find the translations to Paragon.
	If someone finds any error let me know in Curse.
	I will love to have more translations too.
]]
		
local LOCALE = GetLocale()
local l = {} -- "Paragon"

if LOCALE == "esES" or LOCALE == "esMX" then
	l = "Paragón" -- Spanish
elseif LOCALE == "itIT" then
	l = "Eccellenza" -- Italian
elseif LOCALE == "ptBR" then
	l = "Paragão" -- Portuguese
elseif LOCALE == "deDE" then
	l = "Huldigend" -- German
elseif LOCALE == "frFR" then
	l = "Parangon" -- French
elseif LOCALE == "ruRU" then
	l = "Идеал" -- Russian
elseif LOCALE == "koKR" then
	l = "불멸의 동맹" -- Korean
else
	l = "Paragon" -- English (DEFAULT)
end

		----------------------------------------
		-- Get Paragon Reputations and Values --
		----------------------------------------

faction:SetScript("OnEvent",function()
	local factionIndex = 1
	repeat
		local name, _, _, _, _, _, _, _, _, _, _, _, _, factionID = GetFactionInfo(factionIndex);
		if factionID and C_Reputation.IsFactionParagon(factionID) then
			local currentValue = C_Reputation.GetFactionParagonInfo(factionID);
			table.insert(faction,name)
			table.insert(id,factionID)
			table.insert(rep,currentValue)
			table.insert(gained,0)
		end
	factionIndex = factionIndex + 1
	until factionIndex > 200
end)

		--------------------------------
		-- Filter Reputation Messages --
		--------------------------------

ChatFrame_AddMessageEventFilter("CHAT_MSG_COMBAT_FACTION_CHANGE",function(_,_,msg,...)
	for n = 1, #faction do
		local msgrep = gsub(FACTION_STANDING_INCREASED_GENERIC,"%%s",faction[n]);
		if string.match(msgrep, msg) then
			if check == false then
				local currentValue = C_Reputation.GetFactionParagonInfo(id[n]);
				gained[n] = currentValue - rep[n] 
				check = true
			else
				rep[n] = rep[n] + gained[n]
				check = false
			end 
			msg=format(FACTION_STANDING_INCREASED,faction[n],gained[n])
		end
	end
	return false,msg,...
end)

		----------------------
		-- Reputation Frame --
		----------------------

function ReputationFrame_Update(showLFGPulse)
	ReputationFrame.paragonFramesPool:ReleaseAll();

	local numFactions = GetNumFactions();

	if ( not FauxScrollFrame_Update(ReputationListScrollFrame, numFactions, NUM_FACTIONS_DISPLAYED, REPUTATIONFRAME_FACTIONHEIGHT ) ) then
		ReputationListScrollFrameScrollBar:SetValue(0);
	end
	local factionOffset = FauxScrollFrame_GetOffset(ReputationListScrollFrame);

	local gender = UnitSex("player");
	local lfgBonusFactionID = GetLFGBonusFactionID();
	
	for i=1, NUM_FACTIONS_DISPLAYED, 1 do
		local factionIndex = factionOffset + i;
		local factionRow = _G["ReputationBar"..i];
		local factionBar = _G["ReputationBar"..i.."ReputationBar"];
		local factionTitle = _G["ReputationBar"..i.."FactionName"];
		local factionButton = _G["ReputationBar"..i.."ExpandOrCollapseButton"];
		local factionStanding = _G["ReputationBar"..i.."ReputationBarFactionStanding"];
		local factionBackground = _G["ReputationBar"..i.."Background"];
		if ( factionIndex <= numFactions ) then
			local name, description, standingID, barMin, barMax, barValue, atWarWith, canToggleAtWar, isHeader, isCollapsed, hasRep, isWatched, isChild, factionID, hasBonusRepGain, canBeLFGBonus = GetFactionInfo(factionIndex);
			factionTitle:SetText(name);
			if ( isCollapsed ) then
				factionButton:SetNormalTexture("Interface\\Buttons\\UI-PlusButton-Up");
			else
				factionButton:SetNormalTexture("Interface\\Buttons\\UI-MinusButton-Up"); 
			end
			factionRow.index = factionIndex;
			factionRow.isCollapsed = isCollapsed;

			local colorIndex = standingID;
			local factionStandingtext;
			
			local isCapped;
			if (standingID == MAX_REPUTATION_REACTION) then
				isCapped = true;
			end
			local friendID, friendRep, friendMaxRep, friendName, friendText, friendTexture, friendTextLevel, friendThreshold, nextFriendThreshold = GetFriendshipReputation(factionID);
			if (friendID ~= nil) then
				factionStandingtext = friendTextLevel;
				if ( nextFriendThreshold ) then
					barMin, barMax, barValue = friendThreshold, nextFriendThreshold, friendRep;
				else
					barMin, barMax, barValue = 0, 1, 1;
					isCapped = true;
				end
				colorIndex = 5;
				factionRow.friendshipID = friendID;
			else
				factionStandingtext = GetText("FACTION_STANDING_LABEL"..standingID, gender);
				factionRow.friendshipID = nil;
			end	

					---------------------
					-- SetText Paragon --
					---------------------			
			
			if ( factionID and C_Reputation.IsFactionParagon(factionID) ) then
				factionStanding:SetText(l); -- "Paragon" in Reputation Frame. (Customize it if you want)
			else				
				factionStanding:SetText(factionStandingtext);
			end				
			
			barMax = barMax - barMin;
			barValue = barValue - barMin;
			barMin = 0;

					--------------------------
					-- standingText Paragon --
					--------------------------
			
			if ( factionID and C_Reputation.IsFactionParagon(factionID) ) then
				factionRow.standingText = l; -- "Paragon" in Reputation Frame. (Customize it if you want)
			else
				factionRow.standingText = factionStandingtext;
			end		
			
					--------------------------
					-- rolloverText Paragon --
					--------------------------
			
			if ( isCapped and (not C_Reputation.IsFactionParagon(factionID) )) then
				factionRow.rolloverText = nil;
			else
				factionRow.rolloverText = HIGHLIGHT_FONT_COLOR_CODE.." "..format(REPUTATION_PROGRESS_FORMAT, barValue, barMax)..FONT_COLOR_CODE_CLOSE;
			end
			
			factionBar:SetFillStyle("STANDARD_NO_RANGE_FILL");
			factionBar:SetMinMaxValues(0, barMax);
			factionBar:SetValue(barValue);
			local color = FACTION_BAR_COLORS[colorIndex];
			factionBar:SetStatusBarColor(color.r, color.g, color.b);

					--------------------------
					-- Paragon Bars and Bag --
					--------------------------
			
			if ( factionID and C_Reputation.IsFactionParagon(factionID) ) then
				local currentValue, threshold, _, hasRewardPending = C_Reputation.GetFactionParagonInfo(factionID);
				factionBar:SetMinMaxValues(0, threshold);			
				factionBar:SetStatusBarColor(0, 0.5, 0.9); -- R,G,B Colors of the Paragon Bars (Customize it if you want)
				local value = mod(currentValue, threshold);
				if ( hasRewardPending ) then
					local paragonFrame = ReputationFrame.paragonFramesPool:Acquire();
					paragonFrame.factionID = factionID;
					paragonFrame:SetPoint("RIGHT", factionRow, 11, 0);
					paragonFrame:Show();
					value = value + threshold
				end
				factionBar:SetValue(value);
				factionRow.rolloverText = HIGHLIGHT_FONT_COLOR_CODE.." "..format(REPUTATION_PROGRESS_FORMAT, value, threshold)..FONT_COLOR_CODE_CLOSE;
			end	
			
			factionBar.BonusIcon:SetShown(hasBonusRepGain);

			factionRow.LFGBonusRepButton.factionID = factionID;
			factionRow.LFGBonusRepButton:SetShown(canBeLFGBonus);
			factionRow.LFGBonusRepButton:SetChecked(lfgBonusFactionID == factionID);
			factionRow.LFGBonusRepButton:SetEnabled(lfgBonusFactionID ~= factionID);
			if ( showLFGPulse and not SHOWED_LFG_PULSE and not lfgBonusFactionID ) then
				factionRow.LFGBonusRepButton.Glow:Show();
				factionRow.LFGBonusRepButton.GlowAnim:Play();
			else
				factionRow.LFGBonusRepButton.Glow:Hide();
				factionRow.LFGBonusRepButton.GlowAnim:Stop();
			end

			ReputationFrame_SetRowType(factionRow, isChild, isHeader, hasRep);
			
			factionRow:Show();

			if ( atWarWith ) then
				_G["ReputationBar"..i.."ReputationBarAtWarHighlight1"]:Show();
				_G["ReputationBar"..i.."ReputationBarAtWarHighlight2"]:Show();
			else
				_G["ReputationBar"..i.."ReputationBarAtWarHighlight1"]:Hide();
				_G["ReputationBar"..i.."ReputationBarAtWarHighlight2"]:Hide();
			end
			if ( factionIndex == GetSelectedFaction() ) then
				if ( ReputationDetailFrame:IsShown() ) then
					ReputationDetailFactionName:SetText(name);
					ReputationDetailFactionDescription:SetText(description);
					if ( atWarWith ) then
						ReputationDetailAtWarCheckBox:SetChecked(true);
					else
						ReputationDetailAtWarCheckBox:SetChecked(false);
					end
					if ( canToggleAtWar and (not isHeader)) then
						ReputationDetailAtWarCheckBox:Enable();
						ReputationDetailAtWarCheckBoxText:SetTextColor(RED_FONT_COLOR.r, RED_FONT_COLOR.g, RED_FONT_COLOR.b);
					else
						ReputationDetailAtWarCheckBox:Disable();
						ReputationDetailAtWarCheckBoxText:SetTextColor(GRAY_FONT_COLOR.r, GRAY_FONT_COLOR.g, GRAY_FONT_COLOR.b);
					end
					if ( not isHeader ) then
						ReputationDetailInactiveCheckBox:Enable();
						ReputationDetailInactiveCheckBoxText:SetTextColor(ReputationDetailInactiveCheckBoxText:GetFontObject():GetTextColor());
					else
						ReputationDetailInactiveCheckBox:Disable();
						ReputationDetailInactiveCheckBoxText:SetTextColor(GRAY_FONT_COLOR.r, GRAY_FONT_COLOR.g, GRAY_FONT_COLOR.b);
					end
					if ( IsFactionInactive(factionIndex) ) then
						ReputationDetailInactiveCheckBox:SetChecked(true);
					else
						ReputationDetailInactiveCheckBox:SetChecked(false);
					end
					if ( isWatched ) then
						ReputationDetailMainScreenCheckBox:SetChecked(true);
					else
						ReputationDetailMainScreenCheckBox:SetChecked(false);
					end
					ReputationDetailFrame:SetHeight(canBeLFGBonus and 225 or 203);
					ReputationDetailLFGBonusReputationCheckBox:SetShown(canBeLFGBonus);
					ReputationDetailLFGBonusReputationCheckBox:SetChecked(lfgBonusFactionID == factionID);
					ReputationDetailLFGBonusReputationCheckBox.factionID = factionID;
					_G["ReputationBar"..i.."ReputationBarHighlight1"]:Show();
					_G["ReputationBar"..i.."ReputationBarHighlight2"]:Show();
				end
			else
				_G["ReputationBar"..i.."ReputationBarHighlight1"]:Hide();
				_G["ReputationBar"..i.."ReputationBarHighlight2"]:Hide();
			end
		else
			factionRow:Hide();
		end
	end
	if ( GetSelectedFaction() == 0 ) then
		ReputationDetailFrame:Hide();
	end
end